bibliotheca Augustana

<<< Übersicht <<< vorige Seite
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 39. Aventiure
___________________________________________________ #### Aventv wie der herre Dietrich Guntehern vn– Hagenen #### betwanch
| ### o> svchte der herre Dietrich selbe sin gewant ### do half daz er sich wafent maister Hildebrant ### do chlaget also sere der chreftige man ### daz im daz hvs erdiezen gein siner stimme began ### Der helt gewan do widere rehten mannes mvot ### in grimme wart gewafent do der degen gvot ### einen <schilt> vil vesten den nam er an die hant ### nach schaden in do troste der vil chune Hildebrant
###### 2384 | ### Do sprach von Tronege Hagene ich sihe dort her gan ### den herren Dietrichen der wil vns bestan ### nach sinne starchen leide daz im ist hie geschehn ### man sol daz hivte chiesen wem man des besten mvge iehn
###### 2385 | ### lane dvnchet sich von Berne der herre Dietrich ### nie so starch des libes vn– ovch so gremelich ### vn– wil erz an vns rechen daz im ist getan ### also reite Hagene ich tarr in rehte wol bestan
| ### Die rede erhorte Dietrich vn– Hildebrant ### er gie da er die rechen beide stende vant ### vzen vor dem hvse geleinet an den sal ### sinen schilt den gvten den sazte Dietrich zetal
###### 2387 | ### In leitlichen sorgen sprach do Dietrich ### wie habt ir so geworben Gunther ein chunic rich ### ich ellender reche waz ist an mir getan ### alles mines trostes des bin ich eine bestan
###### 2388 | ### Ivch endvhte niht der volle an [87r]der vil grozen not ### do ir vns Rvdegeren den rechen slvget tot ### nv habt ir mir erbunnen aller miner man ### ia het ich iv degenen solher leide niht getan
###### 2389 | ### Gedenchet an ivch selben vn– an iwer leit ### tot der iwer frivnde vn– ovch div arebeit ### ob ez iv gvten degenen beswæret iht den mvot ### owe wie rehte vnsanfte mir tot der Rvdegers tvt
###### 2390 | ### Ez <gescach> in der werlde nie manne leider mer ### ir gedahtet vbele an min vn– an iwer ser ### swaz ich frevden hete div lit von iv erslagen ### iane chan ich nimmer mere die mine mage verchlagen
| ### Iane sin wir niht so schuldich sprach do Hagene ### ez chomen her zem hvse die iwern degene ### ze vlize wol gewafent mit ir schar so breit ### mich dvnchet wie iv div mære niht ze rehte sin geseit
###### 2392 | ### Waz sol ich anders gelovben mir sagtez Hildebrant ### do mine rechen gerten von Amelunge lant ### daz ir in Rvdegere gæbet vz dem sal ### do tat ir niwan spottens die chvnen helde her zetal
###### 2393 | ### Do sprach der kunec von Rine si iahen wolden tragen ### Rvedegeren hinnen den hiez ich in versagen ### Ezeln ze leide vn– niht den dinen man ### vnze daz do Wolfhart dar vmbe schelten began
###### 2394 | ### Do sprach der helt von Berne ez mvese et also sin ### Gunther kunec edele dvrch die zvhte din ### so ergezzet mich der leide die mir sint getan ### vn– svnez ritter chuone so wil ich gar die schulde lan
###### 2395 | ### Ergip dich mir ze gisel dv vn– ovch din man ### so wil ich ivch behvten so ich beste chan ### daz iv hie zen Hvnen niemen niht entvot ### ir svlt an mir niht vinden niwan triwe vn– gvot
| ### Nvne welle got von himele sprach do Hagene ### daz sich dir ergeben zwen degene ### die dv so wærliche sihest gewafent stan ### daz hiez ein michel schande vn– wær ovch vbele getan
###### 2397 | ### Irn svlt ez niht versprechen sprach aber Dietrich ### Gunther vn– Hagene ia habt ir beide mich ### so sere beswæret min herce vn– ovch den mvot ### welt ir mich ergezzen daz irz vil pillichen tvot
###### 2398 | ### Ich gibs iv mine triwe vn– gihtes iv min hant ### daz ich mit iv rite heim in iwer lant ### ich beleite iv nach den eren oder ich gelige tot ### ich wil dvrch ivch verchiesen der minen grozlichen not
###### 2399 | ### Nvne gewæhent sin niht mere sprach aber Hagene ### von <vns> enzimt daz mære niht ze sagene ### daz sich iwer ergæben zwene also chvne man ### nv siht man niemen mære bi iv wan Hildebrande stan
###### 2400 | ### Des antwrt Hildebrant ivch mohte wol gezemen ### den fride mines herren ob ir den rvchet nemen ### ez chvmt noch an die stunde vil liht in churcer cit ### daz ir in gerne næmet vn– in iv danne niemen git
###### 2401 | ### Ja neme ich ê die svone sprach do Hagene ### ê ih [87v]so lasterliche von eime degene ### flvhe meister Hildebrant als ir habt hie getan ### ich wande dar ir kundet baz gein viande stan
| ### Do sprach meister Hildebrant zwiv verwizzet ir mir daz ### nv wer was der vf eime schilde vor dem Waschenstein saz ### do im von Span Walther so vil der frivnde slvoc ### ovch habt ir noch ze zeigen an iv selben genvoc
###### 2403 | ### Do sprach der fvrste Dietrich wie zimt daz helede lip ### daz si svln schelten sam div alten wip ### ich verbivt iv Hildebrant daz ir iht sprechet mer ### mich ellenden rechen twingent grozlichiv ser
###### 2404 | ### Lat hoeren frivnt Hagene sprach do Dietrich ### waz ir ê redetet ir rechen lobelich ### do ir mih gewafent zvo ziv sahet gan ### ir iahet daz ir eine mit strite woldet mich bestan
###### 2405 | ### Iane lovgent iv des niemen sprach Hagene der degen ### ine welle ez hie versvochen mit stichen un– mit slegen ### ez ensi daz mir zebreste daz Nibelunges swert ### mich mvet daz mines herren vn– min ze gisel ist gegert
| ### Do der reche erhorte den grimmen Hagenen mvot ### den schilt vil balde zvchte der snelle degen gvot ### wie balde gein im Hagene von der stiegen spranch ### Nibelunges swert daz gvote vil lvot vf Dietriche erchlanch
###### 2407 | ### Do wesse wol her Dietrich daz der chune man ### vil grimmes mvtes wære schermen im began ### der voget von Berne vor angestlichen slegen ### wol erchander Hagenen er was ein vz erwelter degen
###### 2408 | ### Ovch vorht er Balmungen ein wafen starch genvoc ### vnder wilen Dietrich mit listen wider slvoc ### vnze daz er Hagenen mit strite doch betwanch ### er slvog im eine wnden div was tief vn– lanch
###### 2409 | ### Do daht der herre Dietrich dv bist in not erwigen ### ih han es luzzil ere soltv nv tot geligen ### ich wil ez svs versvchen ob ich ertwingen chan ### dich mir zeinem gisel daz wart mit sorgen getan
###### 2410 | ### Den schilt lie vallen Dietrich sin sterche div was groz ### mit beiden sinen armen er Hagenen vmbesloz ### do wart von im betwngen der vil chvene man ### Gunther der vil edele dar vmbe trvrin began
| ### Hagenen bant do Dietrich vn– fvrt in da er vant ### die edeln Chriemh' vn– gab ir bi der hant ### den chvnisten rechen der ie swert getrvoc ### nach ir vil starchem leide do wart ir liebe genvoc
###### 2412 | ### Vor frevden neich dem rechen daz Ezeln wip ### immer si dir sæli din herce vn– ovch din lip ### dv hast mich wol ergezzet nach aller miner not ### ich sol ez immer dienen mich enwendes der tot
###### 2413 | ### Do sprach der herre Dietrich ir svlt in lan genesen ### vil edeliv kvniginne ez mac vil wol noch wesen ### daz ivch sin dienst ergezzet des er iv hat getan ### er sol des niht engelten daz [88r]man in siht gebunden stan
###### 2414 | ### Do hiez si fvren Hagenen an sin vngemach ### da er lac beslozzen vn– da in niemen sach ### Gunther der kunec edele rvfen do began ### war chom der helt von Berne er hat mir leide getan
| ### Do gie im hin begegene der herre Dietrich ### daz Gunthers ellen daz was so lobelich ### ern beite do niht mere er lief her fvr den sal ### von ir beider swerten hvp sich ein vngefvger schal
###### 2416 | ### Swie vil der herre Dietrich lange was gelobt ### Gunther was so sere erzvrnet vn– ertobt ### wander nach starchen leiden sin herce vient was ### man sagtez noch fvr wnder daz do Dietrich ie genas
###### 2417 | ### Ir ellen vn– ir sterche beide warn groz ### palas vn– tvrne von den slegen doz ### do si mit swerten hewen vf die helme gvot ### ez het der kunic Gunther einen herlichen mvot
###### 2418 | ### Sit twange in der von Berne sam Hagenen ê geschach ### daz blvot man durch die ringe dem helde vliezen sach ### von eime scharpfen swerte daz trvoc her Dietrich ### doch het gewert Gunther nach mvde lobeliche sich
###### 2419 | ### Der herre wart gebunden von Dietriches hant ### swie kunige niene solden liden solhiv bant ### er daht ob er lieze vngebunden wesen ### daz si zwene inme lande niemen liezen genesen
| ### Der vogt von Berne der nam in bi der hant ### do brahter in gebunden da er Chriemh' vant ### do was mit sime leide ir sorge ein teil benomen ### si sprach chunic Gunther sit mir groze willechomen
###### 2421 | ### Er sprach ich soltv nigen vil edel swester min ### ob iwer grvezen moehte genêdichlicher sin ### ich weiz ivch kvniginne so zornic gemvot ### daz ir mir vn– Hagenen vil swachez grvzen getvot
###### 2422 | ### Do sprach der helt von Berne vil edel kuniges wip ### ez enwart nie gisel mere so gvoter ritter lip ### als ich iv frowe here an in gegeben han ### nv svlt ir die ellenden min vil wol geniezen lan
###### 2423 | ### Si iach si tæt iz gerne do gie der chune man ### mit weinenden ovgen von in balde dan ### si rach sich gremliche daz Ezeln wip ### den vz erwelten degenen nam si beiden den lip
###### 2424 | ### Si lie si ligen svnder dvrch ir vngemach ### daz ir sit dewedere den andern nie gesach ### swie ez verlobt hete daz vil edele wip ### si daht ich geriche hivte mins vil lieben mannes lip
###### 2425 | ### Do gie div kuniginne da <si> Hagenen sach ### wie reht erbolgenliche si zvo dem rechen sprach ### welt ir mir geben widere daz ir mir habt genomen ### so mvget ir mit dem lebene wider zen Burgonden chomen
| ### Do sprach der grimme Hagen– [88v]<div> rede ist gar verlorn ### vil edeliv kvniginne ia han ich des gesworn ### daz ich den hort iht zeige die wile deheiner lebe ### der minen edelen herren vn– in niemanne gebe
###### 2427 | ### Er wiste wol div mære sine liezen in niht genesen ### wie mohte ein vntriwe immer stercher wesen ### er vorhte so si hete im sinen lip genomen ### daz si danne ir brvoder lieze heim ze lande chomen
###### 2428 | ### Ich bringez an ein ende gedaht daz edel wip ### do hiez si ir brvoder nemen den lip ### man slvog im abe daz hovbet bi hare si ez trvoc ### fvr den helt von Tronege do warde im leide genvoc
###### 2429 | ### Also der vngemvote sins herren hovbet sach ### wider Chriemh' do der reche sprach ### dv hast ez zeime ende nach dime willen braht ### vn– ist ovch rehte ergangen als ich mir hete gedaht
###### 2430 | ### Nv ist von Bvrgonden der edel kunec tot ### Giselher vn– Volker Danchwart vn– Gernot ### den hort den weiz nv niemen wan got vn– min ### der sol dich vælændinne immer wol verholn sin
| ### Si sprach so habt ir vbele geltes mich gewert ### so wil doch ich behalten daz Sivrides swert ### daz trvoc min holder vriedel do ir im namet den lip ### mortlich mit vntriwen sprach do daz iamerhafte wip
###### 2432 | ### Si zoch ez von der scheiden daz enchunder niht gewern ### do dahte si den rechen des libes vol behern ### si hvbez mit ir handen daz hovpt si im abe slvoc ### daz sach der kunic Ezele do was im leide genvoc
###### 2433 | ### Wafen sprach der furste wie ist nv tot gelegen ### von eines wibes handen der aller beste degen ### der ie chom ze stvrmen oder ie schilt getrvoc ### swie vient ich im wære ez ist mir leide genvoc
###### 2434 | ### Do sprach meister Hildebrant iane genivzet si es niht ### daz si in slahen torste swaz halt mir geschiht ### swie er mich selben bræhte in angestliche not ### idoch so wil ich rechen des vil chvnen rechen tot
| ### Hildebrant mit zorne zvo Chriemh' spranch ### er slvoc der chuniginne einen grimmen swanch ### ia tet ir div sorge von dem degene we ### si mohte lvzzil helfen daz si so angestlichen scre
###### 2436 | ### Do was gelegen aller da der veigen lip ### ze stvchen lac verhowen do daz edel wip ### Ezel vn– Dietrich weinen do began ### si chlageten iæmerliche alle ir mage vn– man
###### 2437 | ### Div vil michel ere was da gelegen tot ### die lvte heten alle iamer vn– not ### mit leide was verendet des kuniges hochgecit ### als ie div liebe leide an dem ende gerne git
###### 2438 | ### Ine chan ivch niht bescheiden waz sider da geshach ### wan christen vn– heiden weinen man do sach ### wibe vn– knehte vn– manige schone meit ### die heten nach ir frivnden div [89r]aller grozisten leit
###### 2439 | ### Ine sage iv nv niht mere von der grozen not ### die da erslagen waren die lazen ligen tot ### wie ir dinch an geviengen sit der Hvnen diet ### hie hat daz mære ein ende daz ist der Nibelunge liet

<<< Übersicht <<< vorige Seite